@@ -16,12 +16,10 @@ from svix.openapi_client.model.endpoint_in import EndpointIn
 from svix.openapi_client.model.endpoint_message_out import EndpointMessageOut
 from svix.openapi_client.model.endpoint_out import EndpointOut
 from svix.openapi_client.model.endpoint_secret_out import EndpointSecretOut
-from svix.openapi_client.model.endpoint_stats import EndpointStats
 from svix.openapi_client.model.event_type_in import EventTypeIn
 from svix.openapi_client.model.event_type_out import EventTypeOut
 from svix.openapi_client.model.event_type_update import EventTypeUpdate
 from svix.openapi_client.model.http_validation_error import HTTPValidationError
-from svix.openapi_client.model.http_error_field import HttpErrorField
 from svix.openapi_client.model.http_error_out import HttpErrorOut
 from svix.openapi_client.model.list_response_application_out import ListResponseApplicationOut
 from svix.openapi_client.model.list_response_endpoint_message_out import ListResponseEndpointMessageOut
